@@ -4,8 +4,8 @@
 
 # Author          : Johan Vromans
 # Created On      : Fri Jul  9 14:32:34 2010
-# Last Modified On: Thu Dec 12 07:57:36 2024
-# Update Count    : 336
+# Last Modified On: Wed Sep 17 12:15:41 2025
+# Update Count    : 339
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -18,7 +18,42 @@ binmode(STDERR, ':utf8');
 binmode(STDOUT, ':utf8');
 
 use FindBin;
-use lib "$FindBin::Bin/../lib";
+
+# @INC construction...
+# Standard paths are lib and lib/ChordPro/lib relative to the parent
+# of the script directory. This may fail if the ChordPro files are installed
+# in another directory than next to the script.
+# Directories in CHORDPRO_XLIBS follow, to augment the path.
+# For example, to add custom delegates.
+# Directories in CHORDPRO_XXLIBS are put in front, these can be used
+# to overrule standard modules. For example, to provide a patches
+# module to an installed kit. Caveat emptor.
+
+my @inc;
+BEGIN {
+  for my $lib ( "$FindBin::Bin/../lib", "$FindBin::Bin/../lib/ChordPro/lib", @INC ) {
+    next unless -d $lib;
+
+    # Is our main module here?
+    if ( -s "$lib/ChordPro.pm" ) {
+	# Prepend override libs.
+	for ( $ENV{CHORDPRO_XXLIBS} ) {
+	    push( @inc, split( $^O =~ /msw/ ? ";" : ":", $_ ) ) if $_;
+	}
+	# Add ChordPro libs.
+	push( @inc, $lib, "$lib/ChordPro/lib" );
+	# Append augment libs.
+	for ( $ENV{CHORDPRO_XLIBS} ) {
+	    push( @inc, split( $^O =~ /msw/ ? ";" : ":", $_ ) ) if $_;
+	}
+    }
+    else {
+	# Copy.
+	push( @inc, $lib );
+    }
+  }
+}
+use lib @inc;
 
 use ChordPro;
 use ChordPro::Paths;
